@@ -2,6 +2,9 @@ package Catalyst::Log;
 
 use strict;
 use base 'Class::Accessor::Fast';
+use Data::Dumper;
+
+$Data::Dumper::Terse = 1;
 
 =head1 NAME
 
@@ -25,6 +28,14 @@ Log debug informations.
 
 sub debug { _format( 'debug', $_[1] ) }
 
+=head3 dump
+
+Dump stuff.
+
+=cut
+
+sub dump { _format( 'dump', Dumper( $_[1] ) ) }
+
 =head3 error
 
 Log error informations.
